#!/bin/bash
source /root/envsetup/envsetup.conf

echo -e "
${RED}Customer parameters will be applied after rebooting. Note that you won't be able to login to the machine after this operation !${NC}"	

# set customer IP (/etc/network/interfaces)
sed -i "s@192\.168\.40\.10.*@${CUST_IP}@" /etc/network/interfaces
sed -i "s@255\.255\.252\..*@${CUST_NETMASK}@" /etc/network/interfaces
sed -i "s@192\.168\.40\..*@${CUST_GATEWAY}@" /etc/network/interfaces

# backup-server specific
if ( test -f /usr/sbin/burp )
then
# changer burp status IP
sed -i "s@^CUST_BURP_MAIL_DEST=.*@CUST_BURP_MAIL_DEST=${CUST_BURP_MAIL_DEST}@" /root/burp-custom.sh
sed -i "s@admin: .*@admin: ${CUST_BURP_MAIL_DEST}" /etc/aliases
newaliases
fi

# set customer DNS
echo "nameserver ${CUST_NS1}" > /etc/resolv.conf
echo "nameserver ${CUST_NS2}" >> /etc/resolv.conf

# set customer NTP
sed -i "s@^server .*@@" /etc/ntp.conf
echo "" >> /etc/ntp.conf
echo "server ${CUST_NTP1}" >> /etc/ntp.conf

if ( ! test -z ${CUST_NTP2} )
then
echo "server ${CUST_NTP2}" >> /etc/ntp.conf
fi

if ( ! test -z ${CUST_NTP3} )
then
echo "server ${CUST_NTP3}" >> /etc/ntp.conf
fi
service ntp restart

# proxy
if [ ${PROXY} = "1" ]
then
	if [ ${PROXY_AUTHENTICATION} = "1" ]
	then
	# APT
	echo "Acquire::http::Proxy \"http://${PROXY_USER}:${PROXY_PASSWD}@${PROXY_HTTP}:${PROXY_PORT}\";" > /etc/apt/apt.conf.d/proxy
	echo "Acquire::https::Proxy \"http://${PROXY_USER}:${PROXY_PASSWD}@${PROXY_HTTP}:${PROXY_PORT}\";" >> /etc/apt/apt.conf.d/proxy
	# /etc/environment
	echo "http_proxy=\"http://${PROXY_USER}:${PROXY_PASSWD}@${PROXY_HTTP}:${PROXY_PORT}\"" >> /etc/environment
	echo "https_proxy=\"http://${PROXY_USER}:${PROXY_PASSWD}@${PROXY_HTTP}:${PROXY_PORT}\"" >> /etc/environment
	else
	# APT
	echo "Acquire::http::Proxy \"http://${PROXY_HTTP}:${PROXY_PORT}\";" > /etc/apt/apt.conf.d/proxy
	echo "Acquire::https::Proxy \"http://${PROXY_HTTP}:${PROXY_PORT}\";" >> /etc/apt/apt.conf.d/proxy
	# /etc/environment
	echo "http_proxy=\"http://${PROXY_HTTP}:${PROXY_PORT}\"" >> /etc/environment
	echo "https_proxy=\"http://${PROXY_HTTP}:${PROXY_PORT}\"" >> /etc/environment
	fi
fi

# MS specific
if ( test -d /usr/local/WowzaStreamingEngine )
then
if [ ${PROXY} = "1" ]
then
# wowza
NB=$(grep -n 'Properties defined here will be added to the IServer.getProperties()' /usr/local/WowzaStreamingEngine/conf/Server.xml | awk -F ":" '{print$1}')
NB_1=$(( ${NB} + 1 ))
NB_MAX=$(wc -l /usr/local/WowzaStreamingEngine/conf/Server.xml | awk '{print$1}')
	if [ ${PROXY_AUTHENTICATION} = "1" ]
	then
	sed -i "${NB_1},${NB_MAX}d" /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Properties>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Name>licenseServerProxyAddress</Name>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Value>${PROXY_HTTP}</Value>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Name>licenseServerProxyPort</Name>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Value>${PROXY_PORT}</Value>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Type>Integer</Type>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Name>licenseServerProxyUsername</Name>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Value>${PROXY_USER}</Value>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Name>licenseServerProxyPassword</Name>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Value>${PROXY_PASSWD}</Value>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Properties>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Server>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Root>	" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	else
	sed -i "${NB_1},${NB_MAX}d" /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Properties>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Name>licenseServerProxyAddress</Name>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Value>${PROXY_HTTP}</Value>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Name>licenseServerProxyPort</Name>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Value>${PROXY_PORT}</Value>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "<Type>Integer</Type>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Property>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Properties>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Server>" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	echo "</Root>	" >> /usr/local/WowzaStreamingEngine/conf/Server.xml
	fi
fi
fi

# set DEFAULT_FROM_EMAIL
if ( ! test -z ${DEFAULT_FROM_EMAIL} )
then
echo "#DEFAULT_FROM_EMAIL = '${DEFAULT_FROM_EMAIL}'" >> /etc/mediaserver/msconf.py
echo "#DEFAULT_FROM_EMAIL = '${DEFAULT_FROM_EMAIL}'" >> /home/skyreach/htdocs/skyreach_site/settings_override.py
fi

# set locale
if [ ${CUST_LOCALE} != 'FR' ]
then
echo -e "${CYAN}You will now change the locales.${NC}"
locale-gen en_GB
locale-gen en_GB.UTF-8
dpkg-reconfigure locales
#~dpkg-reconfigure console-data
dpkg-reconfigure keyboard-configuration
update-locale LANG=en_GB.UTF-8 LANGUAGE=en_GB.UTF-8 LC_ALL=en_GB.UTF-8 LC_MESSAGES=en_GB.UTF-8
fi

# set TZ
if [ ${CUST_TZ} != 'FR' ]
then
echo -e "${CYAN}You will now change the time zone.${NC}"
dpkg-reconfigure tzdata
fi
